---
title: <span class="badge builder"></span> CodeOptions
---
# <span class="badge builder"></span> CodeOptions

## Constructor

```python
CodeOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> text.CodeOptions
```

### <span class="badge object-method"></span> language

The language passed to monaco code editor

```python
def language(language: text.CodeLanguage) -> typing.Self
```

### <span class="badge object-method"></span> show_line_numbers

```python
def show_line_numbers(show_line_numbers: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_mini_map

```python
def show_mini_map(show_mini_map: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CodeOptions](./object-CodeOptions.md)
